@@ -1,8 +1,6 @@
 #!/bin/sh
 set -eou pipefail
-
-export CLUSTER_LOGGING_OPERATOR_NAMESPACE=${CLUSTER_LOGGING_OPERATOR_NAMESPACE:-openshift-logging}
-
+source $(dirname "${BASH_SOURCE[0]}")/env.sh
 
 if oc get project ${CLUSTER_LOGGING_OPERATOR_NAMESPACE} > /dev/null 2>&1 ; then
   echo using existing project ${CLUSTER_LOGGING_OPERATOR_NAMESPACE} for operator installation
@@ -26,7 +24,10 @@ envsubst < olm_deploy/subscription/operator-group.yaml | oc apply -n ${CLUSTER_L
 # create the subscription
 export OPERATOR_PACKAGE_CHANNEL=\"$(grep name manifests/cluster-logging.package.yaml | grep  -oh "[0-9]\+\.[0-9]\+")\"
 echo "Deploying CLO from channel ${OPERATOR_PACKAGE_CHANNEL}"
-envsubst < olm_deploy/subscription/subscription.yaml | oc apply -n ${CLUSTER_LOGGING_OPERATOR_NAMESPACE} -f -
+subscription=$(envsubst < olm_deploy/subscription/subscription.yaml)
+echo "Creating:"
+echo "$subscription"
+echo "$subscription" | oc apply -n ${CLUSTER_LOGGING_OPERATOR_NAMESPACE} -f -
 
 olm_deploy/scripts/wait_for_deployment.sh ${CLUSTER_LOGGING_OPERATOR_NAMESPACE} cluster-logging-operator
 oc wait -n ${CLUSTER_LOGGING_OPERATOR_NAMESPACE} --timeout=180s --for=condition=available deployment/cluster-logging-operator
