@@ -17,11 +17,9 @@ import (
 	"github.com/openshift/cluster-logging-operator/pkg/constants"
 	"github.com/openshift/cluster-logging-operator/pkg/factory"
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
-
 	"github.com/openshift/cluster-logging-operator/pkg/utils/comparators/daemonsets"
 	"github.com/openshift/cluster-logging-operator/pkg/utils/comparators/services"
 	"k8s.io/apimachinery/pkg/api/errors"
-	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -37,6 +35,46 @@ const (
 	fluentdName              = "fluentd"
 	syslogName               = "syslog"
 	fluentdRequiredESVersion = "6"
+	logVolumeMountName       = "varlog"
+	logVolumePath            = "/var/log"
+	logContainers            = "varlogcontainers"
+	logContainersValue       = "/var/log/containers"
+	logPods                  = "varlogpods"
+	logPodsValue             = "/var/log/pods"
+	logJournal               = "varlogjournal"
+	logJournalValue          = "/var/log/journal"
+	logAudit                 = "varlogaudit"
+	logAuditValue            = "/var/log/audit"
+	logOvn                   = "varlogovn"
+	logOvnValue              = "/var/log/ovn"
+	logOauthapiserver        = "varlogoauthapiserver"
+	logOauthapiserverValue   = "/var/log/oauth-apiserver"
+	logOpenshiftapiserver    = "varlogopenshiftapiserver"
+
+	logOpenshiftapiserverValue = "/var/log/openshift-apiserver"
+	logKubeapiserver           = "varlogkubeapiserver"
+	logKubeapiserverValue      = "/var/log/kube-apiserver"
+	config                     = "config"
+	configValue                = "/etc/fluent/configs.d/user"
+	secureforwardconfig        = "secureforwardconfig"
+	secureforwardconfigValue   = "/etc/fluent/configs.d/secure-forward"
+	secureforwardcerts         = "secureforwardcerts"
+	secureforwardcertsValue    = "/etc/ocp-forward"
+	syslogconfig               = "syslogconfig"
+	syslogconfigValue          = "/etc/fluent/configs.d/syslog"
+	syslogcerts                = "syslogcerts"
+	syslogcertsValue           = "/etc/ocp-syslog"
+	entrypoint                 = "entrypoint"
+	entrypointValue            = "/opt/app-root/src/run.sh"
+	certs                      = "certs"
+	certsValue                 = "/etc/fluent/keys"
+	localtime                  = "localtime"
+	localtimeValue             = "/etc/localtime"
+	filebufferstorage          = "filebufferstorage"
+	filebufferstorageValue     = "/var/lib/fluentd"
+	metricsVolumeValue         = "/etc/fluent/metrics"
+	tmp                        = "tmp"
+	tmpValue                   = "/tmp"
 )
 
 func (clusterRequest *ClusterLoggingRequest) removeFluentd() (err error) {
@@ -89,6 +127,11 @@ func (clusterRequest *ClusterLoggingRequest) reconcileFluentdService() error {
 				TargetPort: intstr.FromString(metricsPortName),
 				Name:       metricsPortName,
 			},
+			{
+				Port:       exporterPort,
+				TargetPort: intstr.FromString(exporterPortName),
+				Name:       exporterPortName,
+			},
 		},
 	)
 
@@ -144,6 +187,16 @@ func (clusterRequest *ClusterLoggingRequest) reconcileFluentdServiceMonitor() er
 			// ServerName can be e.g. fluentd.openshift-logging.svc
 		},
 	}
+	logMetricExporterEndpoint := monitoringv1.Endpoint{
+		Port:   exporterPortName,
+		Path:   "/metrics",
+		Scheme: "https",
+		TLSConfig: &monitoringv1.TLSConfig{
+			CAFile:     prometheusCAFile,
+			ServerName: fmt.Sprintf("%s.%s.svc", fluentdName, cluster.Namespace),
+			// ServerName can be e.g. fluentd.openshift-logging.svc
+		},
+	}
 
 	labelSelector := metav1.LabelSelector{
 		MatchLabels: map[string]string{
@@ -153,7 +206,7 @@ func (clusterRequest *ClusterLoggingRequest) reconcileFluentdServiceMonitor() er
 
 	desired.Spec = monitoringv1.ServiceMonitorSpec{
 		JobLabel:  "monitor-fluentd",
-		Endpoints: []monitoringv1.Endpoint{endpoint},
+		Endpoints: []monitoringv1.Endpoint{endpoint, logMetricExporterEndpoint},
 		Selector:  labelSelector,
 		NamespaceSelector: monitoringv1.NamespaceSelector{
 			MatchNames: []string{cluster.Namespace},
@@ -355,6 +408,10 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 		}
 	}
 	fluentdContainer := NewContainer("fluentd", "fluentd", v1.PullIfNotPresent, *resources)
+	// deliberately not passing any resources for running the below container process, let it have cpu and memory as the process requires
+	exporterresources := &v1.ResourceRequirements{}
+
+	exporterContainer := NewContainer("logfilesmetricexporter", "logfilesmetricexporter", v1.PullIfNotPresent, *exporterresources)
 
 	fluentdContainer.Ports = []v1.ContainerPort{
 		{
@@ -364,6 +421,14 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 		},
 	}
 
+	exporterContainer.Ports = []v1.ContainerPort{
+		{
+			Name:          exporterPortName,
+			ContainerPort: exporterPort,
+			Protocol:      v1.ProtocolTCP,
+		},
+	}
+
 	fluentdContainer.Env = []v1.EnvVar{
 		{Name: "NODE_NAME", ValueFrom: &v1.EnvVarSource{FieldRef: &v1.ObjectFieldSelector{APIVersion: "v1", FieldPath: "spec.nodeName"}}},
 		{Name: "METRICS_CERT", Value: "/etc/fluent/metrics/tls.crt"},
@@ -375,13 +440,16 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 	if cluster.Spec.Forwarder != nil {
 		if cluster.Spec.Forwarder.Fluentd.Buffer != nil {
 			if cluster.Spec.Forwarder.Fluentd.Buffer.ChunkLimitSize != "" {
-				chunkLimitSize := resource.MustParse(utils.Transform(string(cluster.Spec.Forwarder.Fluentd.Buffer.ChunkLimitSize)))
-				fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "BUFFER_SIZE_LIMIT", Value: strconv.FormatInt(chunkLimitSize.Value(), 10)})
+				if chunkLimitSize, err := utils.ParseQuantity(string(cluster.Spec.Forwarder.Fluentd.Buffer.ChunkLimitSize)); err == nil {
+					fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "BUFFER_SIZE_LIMIT", Value: strconv.FormatInt(chunkLimitSize.Value(), 10)})
+				}
 			}
 			if cluster.Spec.Forwarder.Fluentd.Buffer.TotalLimitSize != "" {
-				totalLimitSize := resource.MustParse(utils.Transform(string(cluster.Spec.Forwarder.Fluentd.Buffer.TotalLimitSize)))
-				fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "TOTAL_LIMIT_SIZE_PER_BUFFER", Value: strconv.FormatInt(totalLimitSize.Value(), 10)})
+				if totalLimitSize, err := utils.ParseQuantity(string(cluster.Spec.Forwarder.Fluentd.Buffer.TotalLimitSize)); err == nil {
+					fluentdContainer.Env = append(fluentdContainer.Env, v1.EnvVar{Name: "TOTAL_LIMIT_SIZE_PER_BUFFER", Value: strconv.FormatInt(totalLimitSize.Value(), 10)})
+				}
 			}
+
 		}
 	}
 
@@ -389,22 +457,34 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 	fluentdContainer.Env = append(fluentdContainer.Env, proxyEnv...)
 
 	fluentdContainer.VolumeMounts = []v1.VolumeMount{
-		{Name: "varlog", MountPath: "/var/log"},
-		{Name: "varlibdockercontainers", ReadOnly: true, MountPath: "/var/lib/docker"},
-		{Name: "config", ReadOnly: true, MountPath: "/etc/fluent/configs.d/user"},
-		{Name: "secureforwardconfig", ReadOnly: true, MountPath: "/etc/fluent/configs.d/secure-forward"},
-		{Name: "secureforwardcerts", ReadOnly: true, MountPath: "/etc/ocp-forward"},
-		{Name: "syslogconfig", ReadOnly: true, MountPath: "/etc/fluent/configs.d/syslog"},
-		{Name: "syslogcerts", ReadOnly: true, MountPath: "/etc/ocp-syslog"},
-		{Name: "entrypoint", ReadOnly: true, MountPath: "/opt/app-root/src/run.sh", SubPath: "run.sh"},
-		{Name: "certs", ReadOnly: true, MountPath: "/etc/fluent/keys"},
-		{Name: "localtime", ReadOnly: true, MountPath: "/etc/localtime"},
-		{Name: "dockercfg", ReadOnly: true, MountPath: "/etc/sysconfig/docker"},
-		{Name: "dockerdaemoncfg", ReadOnly: true, MountPath: "/etc/docker"},
-		{Name: "filebufferstorage", MountPath: "/var/lib/fluentd"},
-		{Name: metricsVolumeName, MountPath: "/etc/fluent/metrics"},
+		{Name: logContainers, ReadOnly: true, MountPath: logContainersValue},
+		{Name: logPods, ReadOnly: true, MountPath: logPodsValue},
+		{Name: logJournal, ReadOnly: true, MountPath: logJournalValue},
+		{Name: logAudit, ReadOnly: true, MountPath: logAuditValue},
+		{Name: logOvn, ReadOnly: true, MountPath: logOvnValue},
+		{Name: logOauthapiserver, ReadOnly: true, MountPath: logOauthapiserverValue},
+		{Name: logOpenshiftapiserver, ReadOnly: true, MountPath: logOpenshiftapiserverValue},
+		{Name: logKubeapiserver, ReadOnly: true, MountPath: logKubeapiserverValue},
+		{Name: config, ReadOnly: true, MountPath: configValue},
+		{Name: secureforwardconfig, ReadOnly: true, MountPath: secureforwardconfigValue},
+		{Name: secureforwardcerts, ReadOnly: true, MountPath: secureforwardcertsValue},
+		{Name: syslogconfig, ReadOnly: true, MountPath: syslogconfigValue},
+		{Name: syslogcerts, ReadOnly: true, MountPath: syslogcertsValue},
+		{Name: entrypoint, ReadOnly: true, MountPath: entrypointValue, SubPath: "run.sh"},
+		{Name: certs, ReadOnly: true, MountPath: certsValue},
+		{Name: localtime, ReadOnly: true, MountPath: localtimeValue},
+		{Name: filebufferstorage, MountPath: filebufferstorageValue},
+		{Name: metricsVolumeName, ReadOnly: true, MountPath: metricsVolumeValue},
+		{Name: tmp, MountPath: tmpValue},
 	}
 
+	exporterContainer.VolumeMounts = []v1.VolumeMount{
+		{Name: logVolumeMountName, MountPath: logVolumePath},
+		{Name: metricsVolumeName, MountPath: metricsVolumeValue},
+	}
+	// Setting up CMD for log-file-metric-exporter
+	exporterContainer.Command = []string{"/usr/local/bin/log-file-metric-exporter", "  -verbosity=2", " -dir=/var/log/containers", " -http=:2112", " -keyFile=/etc/fluent/metrics/tls.key", " -crtFile=/etc/fluent/metrics/tls.crt"}
+
 	// List of _unique_ output secret names, several outputs may use the same secret.
 	unique := sets.NewString()
 	for _, o := range pipelineSpec.Outputs {
@@ -416,7 +496,7 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 
 	for _, name := range secretNames {
 		path := fmt.Sprintf("/var/run/ocp-collector/secrets/%s", name)
-		fluentdContainer.VolumeMounts = append(fluentdContainer.VolumeMounts, v1.VolumeMount{Name: name, MountPath: path})
+		fluentdContainer.VolumeMounts = append(fluentdContainer.VolumeMounts, v1.VolumeMount{Name: name, ReadOnly: true, MountPath: path})
 	}
 
 	addTrustedCAVolume := false
@@ -432,7 +512,18 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 	}
 
 	fluentdContainer.SecurityContext = &v1.SecurityContext{
-		Privileged: utils.GetBool(true),
+		SELinuxOptions: &v1.SELinuxOptions{
+			Type: "spc_t",
+		},
+		ReadOnlyRootFilesystem:   utils.GetBool(true),
+		AllowPrivilegeEscalation: utils.GetBool(false),
+	}
+	exporterContainer.SecurityContext = &v1.SecurityContext{
+		SELinuxOptions: &v1.SELinuxOptions{
+			Type: "spc_t",
+		},
+		ReadOnlyRootFilesystem:   utils.GetBool(true),
+		AllowPrivilegeEscalation: utils.GetBool(false),
 	}
 
 	tolerations := utils.AppendTolerations(
@@ -453,22 +544,28 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, trustedCABundleCM *v1.Co
 
 	fluentdPodSpec := NewPodSpec(
 		"logcollector",
-		[]v1.Container{fluentdContainer},
+		[]v1.Container{fluentdContainer, exporterContainer},
 		[]v1.Volume{
-			{Name: "varlog", VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: "/var/log"}}},
-			{Name: "varlibdockercontainers", VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: "/var/lib/docker"}}},
-			{Name: "config", VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "fluentd"}}}},
-			{Name: "secureforwardconfig", VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "secure-forward"}, Optional: utils.GetBool(true)}}},
-			{Name: "secureforwardcerts", VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "secure-forward", Optional: utils.GetBool(true)}}},
-			{Name: "syslogconfig", VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: syslogName}, Optional: utils.GetBool(true)}}},
-			{Name: "syslogcerts", VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: syslogName, Optional: utils.GetBool(true)}}},
-			{Name: "entrypoint", VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "fluentd"}}}},
-			{Name: "certs", VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "fluentd", Optional: utils.GetBool(true)}}},
-			{Name: "localtime", VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: "/etc/localtime"}}},
-			{Name: "dockercfg", VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: "/etc/sysconfig/docker"}}},
-			{Name: "dockerdaemoncfg", VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: "/etc/docker"}}},
-			{Name: "filebufferstorage", VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: "/var/lib/fluentd"}}},
+			{Name: logVolumeMountName, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logVolumePath}}},
+			{Name: logContainers, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logContainersValue}}},
+			{Name: logPods, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logPodsValue}}},
+			{Name: logJournal, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logJournalValue}}},
+			{Name: logAudit, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logAuditValue}}},
+			{Name: logOvn, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logOvnValue}}},
+			{Name: logOauthapiserver, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logOauthapiserverValue}}},
+			{Name: logOpenshiftapiserver, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logOpenshiftapiserverValue}}},
+			{Name: logKubeapiserver, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: logKubeapiserverValue}}},
+			{Name: config, VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "fluentd"}}}},
+			{Name: secureforwardconfig, VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "secure-forward"}, Optional: utils.GetBool(true)}}},
+			{Name: secureforwardcerts, VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "secure-forward", Optional: utils.GetBool(true)}}},
+			{Name: syslogconfig, VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: syslogName}, Optional: utils.GetBool(true)}}},
+			{Name: syslogcerts, VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: syslogName, Optional: utils.GetBool(true)}}},
+			{Name: entrypoint, VolumeSource: v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "fluentd"}}}},
+			{Name: certs, VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "fluentd", Optional: utils.GetBool(true)}}},
+			{Name: localtime, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: localtimeValue}}},
+			{Name: filebufferstorage, VolumeSource: v1.VolumeSource{HostPath: &v1.HostPathVolumeSource{Path: filebufferstorageValue}}},
 			{Name: metricsVolumeName, VolumeSource: v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "fluentd-metrics"}}},
+			{Name: tmp, VolumeSource: v1.VolumeSource{EmptyDir: &v1.EmptyDirVolumeSource{Medium: v1.StorageMediumMemory}}},
 		},
 		collectionSpec.Logs.FluentdSpec.NodeSelector,
 		tolerations,
