@@ -17,7 +17,6 @@ import (
 	"time"
 
 	"github.com/ViaQ/logerr/log"
-
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/pkg/constants"
 	v1 "k8s.io/api/core/v1"
@@ -33,9 +32,10 @@ const (
 
 // COMPONENT_IMAGES are thee keys are based on the "container name" + "-{image,version}"
 var COMPONENT_IMAGES = map[string]string{
-	"curator":             "CURATOR_IMAGE",
-	constants.FluentdName: constants.FluentdImageEnvVar,
-	"kibana":              "KIBANA_IMAGE",
+	"curator":                            "CURATOR_IMAGE",
+	constants.FluentdName:                constants.FluentdImageEnvVar,
+	"kibana":                             "KIBANA_IMAGE",
+	constants.LogfilesmetricexporterName: constants.LogfilesmetricImageEnvVar,
 }
 
 // GetAnnotation returns the value of an annoation for a given key and true if the key was found
@@ -330,6 +330,12 @@ func PodVolumeEquivalent(lhs, rhs []v1.Volume) bool {
 				}
 				continue
 			}
+			if lhsVol.EmptyDir != nil && rhsVol.EmptyDir != nil {
+				if lhsVol.EmptyDir.Medium != rhsVol.EmptyDir.Medium {
+					return false
+				}
+				continue
+			}
 
 			return false
 		} else {
@@ -446,12 +452,3 @@ func WrapError(err error) error {
 func ToJsonLogs(logs []string) string {
 	return fmt.Sprintf("[%s]", strings.Join(logs, ","))
 }
-
-// Transforming input value to binary notation
-func Transform(value string) string {
-	if !strings.HasSuffix(value, "i") {
-		value = strings.ToUpper(value)
-		value += "i"
-	}
-	return value
-}
