@@ -56,13 +56,12 @@ var _ = Describe("[ClusterLogForwarder] Forwards logs", func() {
 	  flush_mode interval
 	  flush_interval 1s
 	  flush_thread_count 2
-	  flush_at_shutdown true
 	  retry_type exponential_backoff
 	  retry_wait 1s
 	  retry_max_interval 300s
 	  retry_forever true
 	  queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-	  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }"
+	  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }"
 	  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 	  overflow_action block
 	</buffer>
