@@ -3,8 +3,6 @@ package normalization
 import (
 	"encoding/json"
 	"fmt"
-	"strings"
-
 	"github.com/ViaQ/logerr/log"
 	"github.com/google/go-cmp/cmp"
 	. "github.com/onsi/ginkgo"
@@ -13,6 +11,8 @@ import (
 	"github.com/openshift/cluster-logging-operator/pkg/utils"
 	"github.com/openshift/cluster-logging-operator/test/functional"
 	"github.com/openshift/cluster-logging-operator/test/helpers/types"
+	. "github.com/openshift/cluster-logging-operator/test/matchers"
+	"strings"
 )
 
 const (
@@ -89,11 +89,18 @@ const (
 
 var _ = Describe("[LogForwarding] Json log parsing", func() {
 	var (
-		framework *functional.FluentdFunctionalFramework
-		clfb      *functional.ClusterLogForwarderBuilder
-		expected  map[string]interface{}
-		empty     map[string]interface{}
+		framework       *functional.FluentdFunctionalFramework
+		clfb            *functional.ClusterLogForwarderBuilder
+		expected        map[string]interface{}
+		empty           map[string]interface{}
+		expectedMessage string
+		normalizeJson   = func(json string) string {
+			json = strings.TrimSpace(strings.ReplaceAll(json, "\n", ""))
+			json = strings.ReplaceAll(json, "\t", "")
+			return strings.ReplaceAll(json, " ", "")
+		}
 	)
+
 	BeforeEach(func() {
 		_ = json.Unmarshal([]byte(Json), &expected)
 		empty = map[string]interface{}{}
@@ -101,6 +108,8 @@ var _ = Describe("[LogForwarding] Json log parsing", func() {
 		clfb = functional.NewClusterLogForwarderBuilder(framework.Forwarder).
 			FromInput(logging.InputNameApplication).
 			ToFluentForwardOutput()
+
+		expectedMessage = normalizeJson(Json)
 	})
 	AfterEach(func() {
 		framework.Cleanup()
@@ -108,15 +117,14 @@ var _ = Describe("[LogForwarding] Json log parsing", func() {
 
 	It("should parse json message into structured", func() {
 		clfb.Forwarder.Spec.Pipelines[0].Parse = "json"
-		Expect(framework.Deploy()).To(BeNil())
+		ExpectOK(framework.Deploy())
 
 		// Log message data
-		expectedMessage := strings.ReplaceAll(Json, "\n", "")
 		applicationLogLine := functional.CreateAppLogFromJson(Json)
 		Expect(framework.WriteMessagesToApplicationLog(applicationLogLine, 10)).To(BeNil())
 
 		// Read line from Log Forward output
-		raw, err := framework.ReadRawApplicationLogsFrom(logging.OutputTypeFluentdForward)
+		raw, err := framework.ReadApplicationLogsFrom(logging.OutputTypeFluentdForward)
 		Expect(err).To(BeNil(), "Expected no errors reading the logs")
 
 		// Parse log line
@@ -130,10 +138,10 @@ var _ = Describe("[LogForwarding] Json log parsing", func() {
 			fmt.Printf("diff %s\n", diff)
 		}
 		Expect(same).To(BeTrue(), "parsed json message not matching")
-		fmt.Printf("Message: %s\n", logs[0].Message)
+		log.V(2).Info("Received", "Message", logs[0].Message)
 		diff := cmp.Diff(logs[0].Message, expectedMessage)
-		fmt.Printf("diff %s\n", diff)
-		Expect(logs[0].Message).To(Equal(expectedMessage), "received message not matching")
+		log.V(2).Info("Received", "Diff", diff)
+		Expect(normalizeJson(logs[0].Message)).To(Equal(expectedMessage), "received message not matching")
 	})
 	It("should not parse non json message into structured", func() {
 		clfb.Forwarder.Spec.Pipelines[0].Parse = "json"
@@ -148,7 +156,7 @@ var _ = Describe("[LogForwarding] Json log parsing", func() {
 		Expect(framework.WriteMessagesToApplicationLog(applicationLogLine, 10)).To(BeNil())
 
 		// Read line from Log Forward output
-		raw, err := framework.ReadRawApplicationLogsFrom(logging.OutputTypeFluentdForward)
+		raw, err := framework.ReadApplicationLogsFrom(logging.OutputTypeFluentdForward)
 		Expect(err).To(BeNil(), "Expected no errors reading the logs")
 
 		// Parse log line
@@ -165,15 +173,13 @@ var _ = Describe("[LogForwarding] Json log parsing", func() {
 	})
 	It("should not parse json if not configured", func() {
 		// Pipeline.Parse is not set
-		Expect(framework.Deploy()).To(BeNil())
+		ExpectOK(framework.Deploy())
 
-		expectedMessage := strings.ReplaceAll(Json, "\n", "")
-
-		applicationLogLine := functional.CreateAppLogFromJson(Json)
+		applicationLogLine := functional.CreateAppLogFromJson(expectedMessage)
 		Expect(framework.WriteMessagesToApplicationLog(applicationLogLine, 10)).To(BeNil())
 
 		// Read line from Log Forward output
-		raw, err := framework.ReadRawApplicationLogsFrom(logging.OutputTypeFluentdForward)
+		raw, err := framework.ReadApplicationLogsFrom(logging.OutputTypeFluentdForward)
 		Expect(err).To(BeNil(), "Expected no errors reading the logs")
 
 		// Parse log line
@@ -194,12 +200,11 @@ var _ = Describe("[LogForwarding] Json log parsing", func() {
 
 		// Write log line as input to fluentd
 		expectedMessage := invalidJson
-		message := strings.ReplaceAll(invalidJson, "\"", "\\\"")
-		applicationLogLine := fmt.Sprintf("%s stdout F %s", timestamp, message)
+		applicationLogLine := fmt.Sprintf("%s stdout F %s", timestamp, expectedMessage)
 		Expect(framework.WriteMessagesToApplicationLog(applicationLogLine, 10)).To(BeNil())
 
 		// Read line from Log Forward output
-		raw, err := framework.ReadRawApplicationLogsFrom(logging.OutputTypeFluentdForward)
+		raw, err := framework.ReadApplicationLogsFrom(logging.OutputTypeFluentdForward)
 		Expect(err).To(BeNil(), "Expected no errors reading the logs")
 
 		// Parse log line
