@@ -11,7 +11,9 @@ import (
 	"strings"
 	"time"
 
+	"github.com/openshift/cluster-logging-operator/test"
 	"github.com/openshift/cluster-logging-operator/test/helpers/types"
+	"sigs.k8s.io/controller-runtime/pkg/client/config"
 
 	v1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -21,10 +23,8 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/rest"
-	"k8s.io/client-go/tools/clientcmd"
 
 	clolog "github.com/ViaQ/logerr/log"
-	"github.com/onsi/ginkgo"
 	cl "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/pkg/certificates"
@@ -409,7 +409,7 @@ func (tc *E2ETestFramework) CreateClusterLogForwarder(forwarder *logging.Cluster
 }
 
 func (tc *E2ETestFramework) Cleanup() {
-	if ginkgo.CurrentGinkgoTestDescription().Failed {
+	if g, ok := test.GinkgoCurrentTest(); ok && g.Failed {
 		//allow caller to cleanup if unset (e.g script cleanup())
 		clolog.Info("Running Cleanup script ....")
 		doCleanup := strings.TrimSpace(os.Getenv("DO_CLEANUP"))
@@ -558,16 +558,9 @@ func (tc *E2ETestFramework) CleanFluentDBuffers() {
 
 //NewKubeClient returns a client using the KUBECONFIG env var or incluster settings
 func NewKubeClient() (*kubernetes.Clientset, *rest.Config) {
-
-	var config *rest.Config
-	var err error
-	if kubeconfig := os.Getenv("KUBECONFIG"); kubeconfig != "" {
-		config, err = clientcmd.BuildConfigFromFlags("", kubeconfig)
-	} else {
-		config, err = rest.InClusterConfig()
-	}
+	config, err := config.GetConfig()
 	if err != nil {
-		panic(err.Error())
+		panic(err)
 	}
 	clientset, err := kubernetes.NewForConfig(config)
 	if err != nil {
