@@ -30,6 +30,7 @@ type ContainerLog struct {
 	Level            string                 `json:"level"`
 	Hostname         string                 `json:"hostname"`
 	PipelineMetadata PipelineMetadata       `json:"pipeline_metadata"`
+	LogType          string                 `json:"log_type,omitempty"`
 	ViaqIndexName    string                 `json:"viaq_index_name"`
 	ViaqMsgID        string                 `json:"viaq_msg_id"`
 	Openshift        OpenshiftMeta          `json:"openshift"`
@@ -103,6 +104,7 @@ type JournalLog struct {
 	Hostname            string           `json:"hostname,omitempty"`
 	PipelineMetadata    PipelineMetadata `json:"pipeline_metadata,omitempty"`
 	Timestamp           time.Time        `json:"@timestamp,omitempty"`
+	LogType             string           `json:"log_type,omitempty"`
 	ViaqIndexName       string           `json:"viaq_index_name,omitempty"`
 	ViaqMsgID           string           `json:"viaq_msg_id,omitempty"`
 	Kubernetes          Kubernetes       `json:"kubernetes,omitempty"`
@@ -145,6 +147,7 @@ type InfraLog struct {
 	Hostname            string           `json:"hostname,omitempty"`
 	PipelineMetadata    PipelineMetadata `json:"pipeline_metadata,omitempty"`
 	Timestamp           time.Time        `json:"@timestamp,omitempty"`
+	LogType             string           `json:"log_type,omitempty"`
 	ViaqIndexName       string           `json:"viaq_index_name,omitempty"`
 	ViaqMsgID           string           `json:"viaq_msg_id,omitempty"`
 	STREAMID            string           `json:"_STREAM_ID,omitempty"`
@@ -158,6 +161,7 @@ Audit logs are
  - Audit logs generated by linux
  - Audit logs generated by kubernetes
  - Audit logs generated by openshift
+ - Audit logs generated by Openshift virtual network
 */
 
 // LinuxAuditLog is generated by linux operating system
@@ -167,6 +171,7 @@ type LinuxAuditLog struct {
 	Message          string           `json:"message"`
 	PipelineMetadata PipelineMetadata `json:"pipeline_metadata"`
 	Timestamp        time.Time        `json:"@timestamp"`
+	LogType          string           `json:"log_type,omitempty"`
 	ViaqIndexName    string           `json:"viaq_index_name"`
 	ViaqMsgID        string           `json:"viaq_msg_id"`
 	Kubernetes       Kubernetes       `json:"kubernetes"`
@@ -180,6 +185,19 @@ type AuditLinux struct {
 	RecordID string `json:"record_id,omitempty"`
 }
 
+// OVN Audit log
+type OVNAuditLog struct {
+	Hostname         string           `json:"hostname"`
+	Message          string           `json:"message"`
+	PipelineMetadata PipelineMetadata `json:"pipeline_metadata"`
+	Timestamp        time.Time        `json:"@timestamp"`
+	LogType          string           `json:"log_type,omitempty"`
+	ViaqIndexName    string           `json:"viaq_index_name"`
+	ViaqMsgID        string           `json:"viaq_msg_id"`
+	Kubernetes       Kubernetes       `json:"kubernetes"`
+	Level            string           `json:"level,omitempty"`
+}
+
 // AuditLogCommon is common to k8s and openshift auditlogs
 type AuditLogCommon struct {
 	Kind                     string           `json:"kind,omitempty"`
@@ -201,6 +219,7 @@ type AuditLogCommon struct {
 	Hostname                 string           `json:"hostname,omitempty"`
 	PipelineMetadata         PipelineMetadata `json:"pipeline_metadata,omitempty"`
 	Timestamp                time.Time        `json:"@timestamp,omitempty"`
+	LogType                  string           `json:"log_type,omitempty"`
 	ViaqIndexName            string           `json:"viaq_index_name,omitempty"`
 	ViaqMsgID                string           `json:"viaq_msg_id,omitempty"`
 	Kubernetes               Kubernetes       `json:"kubernetes,omitempty"`
@@ -217,6 +236,7 @@ type EventRouterLog struct {
 	Hostname         string           `json:"hostname,omitempty"`
 	PipelineMetadata PipelineMetadata `json:"pipeline_metadata"`
 	Timestamp        time.Time        `json:"@timestamp"`
+	LogType          string           `json:"log_type,omitempty"`
 	ViaqIndexName    string           `json:"viaq_index_name"`
 	ViaqMsgID        string           `json:"viaq_msg_id"`
 	OpenshiftLabels  OpenshiftMeta    `json:"openshift"`
@@ -264,6 +284,7 @@ type AuditLog struct {
 	Message                  string           `json:"message,omitempty"`
 	PipelineMetadata         PipelineMetadata `json:"pipeline_metadata"`
 	Timestamp                time.Time        `json:"@timestamp,omitempty"`
+	LogType                  string           `json:"log_type,omitempty"`
 	ViaqIndexName            string           `json:"viaq_index_name,omitempty"`
 	ViaqMsgID                string           `json:"viaq_msg_id,omitempty"`
 	Kubernetes               Kubernetes       `json:"kubernetes,omitempty"`
@@ -295,6 +316,7 @@ type AllLog struct {
 	Hostname                 string           `json:"hostname,omitempty"`
 	PipelineMetadata         PipelineMetadata `json:"pipeline_metadata,omitempty"`
 	Timestamp                time.Time        `json:"@timestamp,omitempty"`
+	LogType                  string           `json:"log_type,omitempty"`
 	ViaqIndexName            string           `json:"viaq_index_name,omitempty"`
 	ViaqMsgID                string           `json:"viaq_msg_id,omitempty"`
 	STREAMID                 string           `json:"_STREAM_ID,omitempty"`
